@@ -3,36 +3,32 @@
 ##' @param lines Control stream lines if already read from file
 ##' @param filters.only Return the filters only or also return the remaining text in a separate object? If `FALSE`, a list with the two objects is returned.
 ##' @param as.fun Function to run on the tables with filters.
-##' @keywords internal
+##' @return A `data.frame` with filters
 
-#### Keep internal - will be exported from NMdata
-
-### the aim is to extract and classify filters. classify as IGNORE/ACCEPT, single character or comparisson.
-
-## NMsim() needs a filters argument that can take such a data.frame. It should also accept just a string that represeents the filters if user wants to write something manually.
-
-### NMapplyFilters should translate and apply.
+### belongs in NMdata. Depends on NMdata 0.2.2
 
 NMreadFilters <- function(file,lines,filters.only=TRUE,as.fun) {
+
+    getLines <- NMdata:::getLines
+    NMdataDecideOption <- NMdata:::NMdataDecideOption
+
     
 #### Section start: Dummy variables, only not to get NOTE's in pacakge checks ####
     
     . <- NULL
+    ## data <- NULL
     variable <- NULL
     value <- NULL
     
 ### Section end: Dummy variables, only not to get NOTE's in pacakge checks
     
     if(missing(as.fun)) as.fun <- NULL
-    as.fun <- NMdata:::NMdataDecideOption("as.fun",as.fun)
+    as.fun <- NMdataDecideOption("as.fun",as.fun)
     
     if(missing(lines)) lines <- NULL
     if(missing(file)) file <- NULL
-### this is assuming there is only one file, or that lines contains only one control stream.
-
-    
-    
-    lines <- NMdata:::getLines(file=file,lines=lines)
+### this is assuming there is only one file, or that lines contains only one control stream.    
+    lines <- getLines(file=file,lines=lines)
 
     ## If these are not NULL, it can make trouble in NMreadSection.
     file <- NULL
@@ -57,17 +53,20 @@ NMreadFilters <- function(file,lines,filters.only=TRUE,as.fun) {
     ## ^(.* )* : if anything before IGN, there must be a space in between
     ## conds.sc <- regmatches(text3, gregexpr("^(.* )*(?:IGN) *=* *[^ (+=]",text3))
     conds.sc <- regmatches(text3, gregexpr("(?<![[:alnum:]])IGN *=* *[^ (+=]",text3,perl=T))
-    conds.sc
     conds.sc <- do.call(c,conds.sc)
     
 ### getting rid of single char conditions
     text3 <- gsub("(?<![[:alnum:]])IGN *=* *[^ (+=]","",perl=TRUE,text3)
     
+#### any.accepts, any.ignores, and type.condition only relate to expression-type conditions. ACCEPT can be combined with single-character ignore.
     ## check if IGNORE or ACCEPT are found. If both found, it is an error. 
     any.accepts <- any(grepl("ACCEPT",text3))
-    any.ignores <- any(grepl("IGN",text3))
+    any.ignores <- any(grepl("IGN",text3)) ##||length(conds.sc)
+#### this looks wrong. Why return data if nothing found? Seems like
+#### empty set of filters should be returned.
     ## if no filters found, just return data as is
-    if(!any.accepts && !any.ignores && length(conds.sc)==0) return(data)
+    ## if(!any.accepts && !any.ignores && length(conds.sc)==0) return(data)
+
     if(any.accepts&&any.ignores) stop("IGNORE and ACCEPT are not allowed together according to Nonmem documentation.")
     
     if(any.ignores) {
@@ -90,27 +89,9 @@ NMreadFilters <- function(file,lines,filters.only=TRUE,as.fun) {
     ## name.c1 <- colnames(data)[1]
     scs <- sub(paste0("IGN"," *=* *(.+)"),"\\1",conds.sc)
     scs.all <- scs
-    ## expressions.sc <- c()
-    ## if(length(scs)&&grepl("@",scs)) {
-### NM manual: @ means first non-blank is a-z or A-Z.
-    ##     expressions.sc <- c(expressions.sc,paste0("!grepl(\"^ *[A-Za-z]\",",name.c1,")"))
-    ##     scs <- scs[!grepl("@",scs)]
-    ## }
-    
-    
-### other single character ignores can be any character - except for space
-    ## regstring <- "[[:punct:]]|[[:alpha:]]"
-
-    ## if(length(scs)&&any(grepl(regstring,scs))) {
-    ##     scs2 <- regmatches(scs,regexpr(regstring,scs))
-    ##     expressions.sc <- c(expressions.sc,paste0("!grepl('^[",scs2,"]',`",name.c1,"`)"))
-    ##     scs <- scs[!grepl(regstring,scs)]
-    ## }
-
-    ## if(length(scs)) stop(paste0("Not all single-character IGNORE statements were translated. This is left: ",scs))
 
     
-    ## translating expression-style ones
+    ## translating expression-style ones - they can be separated by commas
     conds.list <- strsplit(
         gsub(paste0(type.condition," *=* *\\((.+)\\)"),"\\1",conds.expr)
        ,split=",")
@@ -122,7 +103,7 @@ NMreadFilters <- function(file,lines,filters.only=TRUE,as.fun) {
         dt.filters <- rbind(
             dt.filters
            ,
-            data.table(type=type.condition,class="single-char",cond=scs.all)
+            data.table(type="IGN",class="single-char",cond=scs.all)
         )
     }
     if(length(conds.char)){
