@@ -1,6 +1,6 @@
 
 ##sprintf("call %s %s %s",path.nonmem,fn.mod,fnExtension(fn.mod,".lst"))
-NMrunWin <- function(fn.mod,dir.mod.abs,exts.cp,meta.tables,path.nonmem,clean,fun.post=NULL){
+NMrunWin <- function(fn.mod,dir.mod.abs,exts.cp,meta.tables,path.nonmem,clean,nmfe.options,fun.post=NULL){
 
 #### Section start: Dummy variables, only not to get NOTE's in pacakge checks ####
 
@@ -18,7 +18,8 @@ NMrunWin <- function(fn.mod,dir.mod.abs,exts.cp,meta.tables,path.nonmem,clean,fu
     }
 
     lines.bat <- c("@echo off",
-                   sprintf("call %s %s %s",path.nonmem,fn.mod,fnExtension(fn.mod,".lst"))
+                   sprintf("call %s %s %s %s",
+                           path.nonmem,fn.mod,fnExtension(fn.mod,".lst"),nmfe.options)
                   ,
                    paste(unlist(lapply(fnExtension(fn.mod,exts.cp),cp.if.pres,dest=dir.mod.abs)),collapse="\n")
                   ,
